@@ -12,14 +12,16 @@ import aws_cdk.aws_autoscaling._jsii
 import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_ecs._jsii
+import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_rds._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-keycloak", "0.0.2", __name__[0:-6], "cdk-keycloak@0.0.2.jsii.tgz"
+    "cdk-keycloak", "0.0.10", __name__[0:-6], "cdk-keycloak@0.0.10.jsii.tgz"
 )
 
 __all__ = [
